% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readAdat.R
\name{readAdat}
\alias{readAdat}
\title{Read a SomaLogic data file}
\usage{
readAdat(file, keepOnlyPasses = TRUE, keepOnlySamples = TRUE,
  dateFormat = "\%Y-\%m-\%d", verbose = getOption("verbose"))
}
\arguments{
\item{file}{A string containing the path to the file to be read.}

\item{keepOnlyPasses}{A logical value indicating whether or not to keep
only the rows and columns where the data quality was considered to be
passable.}

\item{keepOnlySamples}{A logical value indicating whether or not to keep
only the rows containing actual samples (as opposed to QC, buffer, and
calibrator samples).}

\item{dateFormat}{A string describing the format of the dates contained in
the file's metadata.  See \code{\link[base]{strptime}} for how to specify
these.}

\item{verbose}{Logical value indicating whether (lots of) diagnostic messages
should be shown.}
}
\value{
An object of class \code{WideSomaLogicData}, which inherits from
\code{data.table}.
The return value consists of a data frame where each row represents a
sample.  Initial columns contain sample metadata and later columns contain
intensities of proteins.  The specific metadata columns are not fixed, but
the most useful ones described below should always be present.
\describe{
\item{SampleUniqueID}{A unique identifier for the sample.}
\item{Subject_ID}{A unique identifier for the person being sampled.}
\item{RowCheck}{This should have the value "PASS" if the data quality is
acceptable.}
}
Columns of proteins intensities have a name beginning \code{SeqId.}.
Return value also has three attributes.
\describe{
\item{SequenceData}{A data frame.}
\item{Metadata}{A list of experimental metadata values.}
\item{Checksum}{A SHA1 checksum to ensure file integrity.}
}
}
\description{
Reads a SomaLogic ADAT data file.
}
\examples{
somaFile <- extractSampleData()
wideSomaData <- readAdat(somaFile)
str(wideSomaData, list.len = 35)
unlink(somaFile)
}
\author{
Richard Cotton
}

